import path from 'path';
import process from 'process';
import webpack from 'webpack';
import TerserPlugin from 'terser-webpack-plugin';
import BDWP from 'bundle-declarations-webpack-plugin';
const isProduction = process.env.NODE_ENV == 'production';
const generalConfig = {
    entry: './varsnap/index.ts',
    plugins: [
        // Add your plugins here
        // Learn more about plugins from https://webpack.js.org/configuration/plugins/
        new BDWP(),
        new webpack.BannerPlugin({
            banner: 'Varsnap.js v1.11.3',
        }),
    ],
    module: {
        rules: [
            {
                test: /\.(ts|tsx)$/i,
                loader: 'ts-loader',
                exclude: ['/node_modules/'],
            },
            // Add your rules for custom modules here
            // Learn more about loaders from https://webpack.js.org/loaders/
        ],
    },
    resolve: {
        extensions: ['.tsx', '.ts', '.jsx', '.js', '...'],
        alias: {
            './core.js': path.resolve('varsnap/core.ts'),
        },
    },
    optimization: {
        minimize: isProduction,
        minimizer: [new TerserPlugin({
                extractComments: false,
            })],
    }
};
const nodeConfig = {
    devtool: 'source-map',
    target: 'node',
    output: {
        path: path.resolve('./dist'),
        filename: isProduction ? 'node.min.cjs' : 'node.cjs',
        globalObject: 'this',
        library: {
            name: 'varsnap',
            type: 'umd',
            export: 'default',
        },
    },
};
const browserConfig = {
    devtool: 'source-map',
    target: 'web',
    output: {
        path: path.resolve('./dist'),
        filename: isProduction ? 'browser.min.js' : 'browser.js',
        globalObject: 'this',
        library: {
            name: 'varsnap',
            type: 'umd',
            export: 'default',
        },
    },
};
export default () => {
    if (isProduction) {
        generalConfig.mode = 'production';
    }
    else {
        generalConfig.mode = 'development';
    }
    Object.assign(nodeConfig, generalConfig);
    Object.assign(browserConfig, generalConfig);
    return [nodeConfig, browserConfig];
};
//# sourceMappingURL=webpack.config.js.map